Django RestFramework pagination For bootstrap-table
===================================================
A Pagination plugin for [Django rest framework](http://www.django-rest-framework.org/) to suite [Bootstrap Table](http://bootstrap-table.wenzhixin.net.cn/)



Installation
------------

Install the latest version with pip:

```bash
$ pip rest_bootstraptable_pagination
```

